@@ -6,7 +6,7 @@ Copyright (c) 2013, Wladston Viana.
 """
 
 __author__ = 'Wladston Viana'
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 __license__ = 'MIT'
 
 # Python.
@@ -19,7 +19,6 @@ from pymongo.son_manipulator import SONManipulator
 
 connection = None
 db = None
-_manipulators = []
 
 # MongoDB will not store dates with milliseconds.
 milli_trim = lambda x: x.replace(microsecond=int((x.microsecond/1000)*1000))
@@ -27,14 +26,10 @@ milli_trim = lambda x: x.replace(microsecond=int((x.microsecond/1000)*1000))
 
 def setup(database_name):
     global db, connection, _manipulators
+
     connection = MongoClient('localhost', 27017, tz_aware=True)
     db = getattr(connection, database_name)
 
-    for x in _manipulators:
-        db.add_son_manipulator(x)
-
-    _manipulators = []
-
     return db
 
 
@@ -126,15 +121,12 @@ class ModelType(type):
                 dct['_fields'][attr] = val
                 dct[attr] = property(cls.get_maker(attr), cls.set_maker(attr))
 
-        cls = super(ModelType, cls).__new__(cls, name, bases, dct)
+        rich_cls = super(ModelType, cls).__new__(cls, name, bases, dct)
 
-        if db:
-            db.add_son_manipulator(_ModelManipulator(cls))
+        if rich_cls.__name__ not in ['Model', 'Document', 'TimeStampedModel']:
+            db.add_son_manipulator(_ModelManipulator(rich_cls))
 
-        else:
-            _manipulators.append(_ModelManipulator(cls))
-
-        return cls
+        return rich_cls
 
 
 class Field(object):
